VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsOutputDriver"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
' Dies ist die Hauptklasse des Plugins.
' Bei Ausgabeplugins gibt es prinzipiell zwei Mglichkeiten:
' 1. Falls das Interface einzelne Kanal-nderungen erwartet, knnen diese direkt an das Interface
'    gesendet werden
' 2. Wenn das Interface das ganze DMX-Universe auf einmal erwartet, mssen die einzelnen Kanalwerte
'    in einem Array zwischengespeichert werden. Dann kann z.B. ein Timer sie regelmig in das
'    Interface schreiben.
'
' Um DMX-In-Werte an DMXControl zu bergeben, wird die Funktion DMXC_DMXIn_SetChannel des Objektes
' DMXCPluginHelper verwendet.
'
' In diesem Beispiel wird Mglichkeit 2 gezeigt. Die DMX-In-Werte werden in frmMain.timInput_Timer erzeugt.
'
' Plugins haben einen bestimmen Lebenszyklus:
' 1. Beim Start von DMXControl werden alle gefundenen Plugins initialisiert (Funktion "Init").
'    Dabei werden einige Informationen bergeben, unter anderem ein Objekt, durch das das Plugin mit
'    DMXC kommunizieren kann.
'    Zu diesem Zeitpunkt sollte das Plugin z.B. Einstellungen laden und alles fr die sptere Arbeit
'    vorbereiten, jedoch mglicht wenig Ressourcen verbrauchen, da nicht klar ist ob es berhaupt
'    aktiviert wird. Auf keinen Fall drfen hier irgendwelche Ports geffnet oder Einstellungen
'    abgefragt werden.
' 2. Wenn das Plugin aktiviert ist, wird die Funktion "Enable" aufgerufen. Jetzt sollte das Plugin
'    eventuell bentigte Schnittstellen ffnen und mit der DMX-Ausgabe beginnen.
' 3. Wird DMXC beendet oder der Benutzer deaktiviert das Plugin, wird die Funktion "Disable" aufgerufen.
'    Hier sollte das Plugin die DMX-Ausgabe beenden und belegte Ports wieder freigeben. Danach sollte
'    es fr einen eventuellen neuen "Enable"-Aufruf vorbereitet sein.
' 4. Beim Beenden von DMXControl werden alle Plugins terminiert. Vorher wird die Funktion "Term" aufgerufen.
'    Das Plugin sollte dann seine Einstellungen speichern und alle belegten Ressourcen freigeben.


' This is the main-class of the plugin.
' There are always two possibilities:
' 1. If the interface expects one-channel-changings then they can be sent to it directly.
' 2. If the interface expects the whole universe then the single DMX-channel-values have to be cached in an array.
'    e.g. then the timer can send it regulary.
'
' The function DMXC_DMXIn_SetChannel (object of DMXCPlunginHelper) is used to transfer the DMX-IN-value to DMXControl.
'
' In this instace method 2 is shown. The DMX-In-values are created in frmMain.timInput_Timer.
'
' Plugins have a special circle of life:
' 1. DMXControl initialises every plugin at startup (function "Init").
'    There are submitted some information among other things an object through which DMXControl is able to communicate with the plugin.
'    In this moment the plugin should e.g. load settings an prepare all for later work but with the use of less ressources because it is not
'    sure whether the plugin will be activated. In no case ports were opened or settings were queried there.
' 2. If the plugin is enabled the function "Enable" will be called. Now, the plugin should open eventually needed interfaces and should begin
'    with the DMX-output.
' 3. If the user closes DMXControl or disables the plugin the function "Disable" will be called. Now, the plugin should stop the DMX-output and
'    release engaged ports. Then it should be prepared for a new "Enable"-call.
' 4. With the closing of DMXControl all plugins will be terminated. Before that the function "Term" is called. Then should it save its settings
'    and release engaged ressources.


Option Explicit

' Name des Aufrufenden Programms, wird fr Registry-Zugriffe verwendet
' Name of the calling program, this is used for registry queries
Private CallingApp As String
' Dateiname der Plugin-Instanz. Wichtig wenn mehrere Kopien des Plugins verwendet werden.
' Filename of plugin-instance. Important when more than one copy of the plugin is used.
Private mFilename As String
' Diese Funktion wird aufgerufen, wenn das Plugin deaktiviert wird.
' Hier sollten die DMX-Ausgabe beendet und eventuell geffnete Ports wieder geschlossen werden
' Rckgabewerte:
'  True:  Kein Fehler aufgetreten
'  False: Fehler aufgetreten
' ===
' This function will be called, if the plugin is deactivated.
' Now the DMX-Output should be stopped an eventually opened ports closed.
' Return-value:
'  True: No error occured
'  False: Error occured
Public Function Disable() As Boolean
 ' Aktuellen Ausgabezustand merken
 ' Remember actual Output-staus
 OutputEnable = False
 
 ' Mglichkeit 1:
 ' Timer fr DMX-Ausgabe deaktivieren
 ' Possibility 1:
 ' Deactivation of the DMX-Output timer
 frmMain.timOutput.Enabled = False
 ' Timer fr DMX-In deaktivieren
 ' Deactivation of the DMX-In timer
 frmMain.timInput.Enabled = False
 
 ' Mglichkeit 2:
 ' Interface deaktivieren
 ' Possibility 2:
 ' Disable the interface
 'DisableDMXInterface()
 
 ' Rckgabewert setzen
 ' Set return value
 Disable = True
End Function
' Diese Funktion wird aufgerufen, wenn das Plugin aktiviert wird.
' Hier sollte die DMX-Ausgabe gestartet werden.
' Rckgabewerte:
'  True:  Kein Fehler aufgetreten
'  False: Fehler aufgetreten
' ===
' This function will be called, if the plugin is activated.
' Now the DMX-Output should be started.
' Return-value:
'  True: No error occured
'  False: Error occured
Public Function Enable() As Boolean
 ' Aktuellen Ausgabezustand merken
 ' Remember actual Output-staus
 OutputEnable = True
 
 ' Mglichkeit 1:
 ' Timer fr DMX-Ausgabe aktivieren
 ' Possibility 1:
 ' Activation of the DMX-In timer
 frmMain.timOutput.Enabled = True
 ' Wenn DMX-In in den Einstellungen aktiviert wurde...
 ' If the DMX-In is activated in the settings...
 If DMXInActive Then
  ' ...Timer fr DMX-In aktivieren.
  ' ...enable timer for DMX-In.
  frmMain.timInput.Enabled = True
 End If
 
 ' Mglichkeit 2:
 ' Interface aktivieren
 ' Possibility 2:
 ' Activate interface
 'EnableDMXInterface()
 
 ' Rckgabewert setzen
 ' Set return value
 Enable = True
End Function
' Diese Funktion liefert den Namen des Plugins zurck, so wie DMXControl ihn anzeigen soll.
' Rckgabewerte:
'  Name des Plugins
' ===
' This fuction returns the name of the plugin like DMXControl shows it.
' Return value:
' Name of the plugin
Public Function PluginName() As String
 ' Rckgabewert setzen
 ' set return value
 PluginName = "Sample Plugin with DMX-in"
End Function
' Diese Funktion wird aufgerufen, wenn ein neuer Wert auf einem Kanal ausgegeben werden soll.
' Eingabewerte:
'  Channel: Zu ndernder Kanal, Zhlung beginnt bei 1
'  Value: Neuer Wert fr den Kanal, 0-255
' Rckgabewerte:
'  True:  Kanal gesetzt aufgetreten
'  False: Kanal nicht gesetzt
' ===
' This function will be called, if a new value should be output on a channel.
' Input value:
'  Channel: The channel which should be changed, count begins with 1
'  Value: new value for the channel, 0-255
' Return value:
'  True: channel set appeared
'  False: Channel not set
Public Function SetChannel(Channel As Long, Value As Long) As Boolean
 ' Mglichkeit 1:
 ' Wenn Channel im zulssigen Bereich liegt...
 ' Possibility 1:
 ' If channel lies in the authorized area...
 If Channel >= 1 And Channel <= UBound(DMXValues) Then
  ' DMX-Wert im Array aktualisieren
  ' Update the DMX-value in the array
  DMXValues(Channel) = Value
  ' Rckgabewert setzen (erfolgreich)
  ' Set return value (succesful)
  SetChannel = True
 Else
  ' Rckgabewert setzen
  ' Set return value
  SetChannel = False
 End If
 
 ' Mglichkeit 2:
 ' Wert direkt zum Interface schreiben, Rckgabewert setzen
 ' Possibility 2:
 ' Send value to the interface directly, set return value
 'SetChannel = WriteToDMXInterface(Channel, Value)
End Function
' Diese Funktion wird aufgerufen, wenn der Benutzer das Plugin konfigurieren mchte
' Rckgabewerte:
'  True:  Das Plugin ist konfigurierbar
'  False: Das Plugin nicht konfigurierbar
' ===
' This function ist called when then user wants to configure the plugin.
' Return values:
'  True:  Plugin is configurable
'  False: Plugin is not configurable
Public Function Configure() As Boolean
 ' Konfigurationsfenster modal anzeigen
 ' Show configuration form
 frmConfig.Show vbModal
 
 ' Rckgabewert setzen
 ' Set return value
 Configure = True
End Function
' Diese Funktion wird aufgerufen, wenn das Plugin initialisiert wird.
' Hier sollten Einstellungen geladen und alles fr das aktivieren vorbereitet werden.
' Es drfen noch keine Ports belegt werden!
' Eingabewerte:
'  CallingAppTitle:  Name der aufrufenden Anwendung
'  MyFilename:       Dateiname dieser Plugin-Instanz
'  DMXCPluginHelper: Referenz auf den fr dieses Plugin zustndigen PluginHelper
' Rckgabewerte:
'  True:  Kein Fehler aufgetreten
'  False: Fehler aufgetreten
' ===
' This fuction will be called if the plugins is initalised.
' Here are the settings loaded and all the stuff you need for the activation prepared.
' It is not allowed to engage ports at this time.
' Input values:
'  CallingAppTitle:  Name of the called application
'  MyFilename:       Filename of this plugin instance
'  DMXCPluginHelper: Reference for the PluginHelper who is responsible for this plugin
' Return values:
'  True: no error occured
'  False: Error occured
Public Function Init(ByRef CallingAppTitle As String, ByRef MyFilename As String, ByRef DMXCPluginHelper As Object) As Boolean
 ' Wichtige Werte aufbewahren
 ' Store important values
 CallingApp = CallingAppTitle
 mFilename = MyFilename
 Set mHelper = DMXCPluginHelper
 
 ' Hauptformular laden (enthlt Timer)
 ' Load main form (includes the timer)
 Load frmMain
 
 ' Einstellungen laden
 ' Load settings
 DMXInActive = GetSetting(CallingApp, "Plugins\" & mFilename, "DMXInActive", True)
End Function
' Diese Funktion wird aufgerufen, wenn das Plugin terminiert wird.
' Hier sollten Einstellungen gespeichert und alle Ressourcen freigegeben werden.
' Rckgabewerte:
'  True:  Kein Fehler aufgetreten
'  False: Fehler aufgetreten
' ===
' This function will be called, if the plugin is terminated.
' Here should settings be saved and all ressources released
' Return values:
'  True: No error occured
'  False: Error occured
' ===
Public Function Term() As Boolean
 ' DMXCPluginHelper freigeben
 ' Release DMXCPluginHelper
 Set mHelper = Nothing
 
 ' Einstellungen speichern
 ' Save settings
 SaveSetting CallingApp, "Plugins\" & mFilename, "DMXInActive", DMXInActive
End Function
Private Sub Class_Initialize()
 Debug.Print "Initialize class"
End Sub


Private Sub Class_Terminate()
 Debug.Print "Terminate class"
End Sub


